repositories

package
v0.0.0-...-f39c433 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 8, 2021 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DB

type DB struct {
	// contains filtered or unexported fields
}

DB represents the application database (json file)

func NewDB

func NewDB(dbPath string, dbCfgPath string) *DB

// NewDB creates a new instance of application file DB

func (*DB) Read

func (d *DB) Read(bs []byte) (int, error)

Read fetches a list of reminders by given ids

func (*DB) Start

func (d *DB) Start() error

Jump to